@@ -7,9 +7,13 @@
 #' @return A nlevels(x) + 1 length vector of percentages
 percent <- function(x)
 {
-  c(NA, summary(x, maxsum = Inf) / length(x)) * 100
+  if (x %>% is.factor)
+    c(NA, summary(x, maxsum = Inf) / length(x)) * 100
+  else
+    NA
 }
 
+
 #' Return the inter-quartile range
 #'
 #' Safe version of IQR for statify
@@ -21,6 +25,7 @@ IQR <- function(x)
   base::diff(stats::quantile(x, c(0.25, 0.75), na.rm = T))
 }
 
+
 #' Test if distribution is normal
 #'
 #' Test if distribution is normal.
@@ -40,6 +45,7 @@ is.normal <- function(x)
     F
 }
 
+
 #' Fisher's Exact Test for Count Data
 #'
 #' Performs Fisher's exact test for testing the null of independence
@@ -190,9 +196,11 @@ fisher.test <- function(x, y, workspace, hybrid, control, or, alternative, conf.
   UseMethod("fisher.test")
 }
 
+
 #' @rdname fisher.test
 fisher.test.default <- function(x, ...) stats::fisher.test(x, ...)
 
+
 #' @rdname fisher.test
 fisher.test.formula <- function(x,
                                 y = NULL,
@@ -219,6 +227,7 @@ fisher.test.formula <- function(x,
                       B = B)
 }
 
+
 #' Pearson's Chi-squared Test for Count Data
 #'
 #' \code{chisq.test} performs chi-squared contingency table tests and goodness-of-fit tests, with an added method for formulas.
@@ -348,10 +357,12 @@ chisq.test <- function(x, y, correct, p, rescale.p, simulate.p.value, B)
   UseMethod("chisq.test")
 }
 
+
 #' @rdname chisq.test
 chisq.test.default <- stats::chisq.test
 
 #' @rdname chisq.test
+
 chisq.test.formula <- function(x,
                                y = NULL,
                                correct = T,
@@ -369,6 +380,7 @@ chisq.test.formula <- function(x,
                      B = B)
 }
 
+
 #' Wrapper for oneway.test(var.equal = T)
 #'
 #' @param formula An anova formula (\code{variable ~ grouping variable})
@@ -379,6 +391,7 @@ ANOVA <- function(formula)
   stats::oneway.test(formula, var.equal = T)
 }
 
+
 #' No test
 #'
 #' An empty test
